#
# spec file for package mandoc
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2024 Mageia.Org
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mandoc
Version:        1.14.6
Release:        %mkrel 4
Summary:        UNIX manpage compiler
License:        ISC
Group:          Text tools
URL:            http://mandoc.bsd.lv/
Source:         http://mandoc.bsd.lv/snapshots/mandoc-%{version}.tar.gz
# PATCH-FIX-UPSTREAM boo1209830-endless-loop.patch bsc#1209830 mcepl@suse.com
# Fix endless loop
Patch0:         boo1209830-endless-loop.patch
BuildRequires:  less
BuildRequires:  locales
BuildRequires:  zlib-devel
Requires:       locales
Provides:       %{name}-bin = %{version}-%{release}
Obsoletes:      %{name}-bin < 1.14.6-3

%description
The mandoc manpage compiler toolset (formerly called "mdocml")
is a suite of tools compiling mdoc(7), the roff(7) macro language
of choice for BSD manual pages, and man(7), the predominant
historical language for UNIX manuals.

%prep
%autosetup -p1

# create configure.local
cat >> configure.local << EOF
PREFIX=%{_prefix}
BINDIR=%{_bindir}
SBINDIR=%{_sbindir}
MANDIR=%{_mandir}
INCLUDEDIR=%{_includedir}
LIBDIR=%{_libdir}

UTF8_LOCALE=C.UTF-8

MANM_MANCONF="mandoc.conf"         # default is "man.conf"
MANM_MAN="mandoc.man"              # default is "man"
MANM_MDOC="mandoc.mdoc"            # default is "mdoc"
MANM_ROFF="mandoc.roff"            # default is "roff"
MANM_EQN="mandoc.eqn"              # default is "eqn"
MANM_TBL="mandoc.tbl"              # default is "tbl"
BINM_MAN=mandoc.man                # default is "man"
BINM_APROPOS=mandoc.apropos        # default is "apropos"
BINM_WHATIS=mandoc.whatis          # default is "whatis"
BINM_MAKEWHATIS=mandoc.makewhatis  # default is "makewhatis"
BINM_SOELIM=mandoc.soelim          # default is "soelim"
BINM_PAGER="less -FR"

# with default settings rpmlint complains about cross-directory hardlinks
LN="ln -sf"

# override the install permissions so that owner-write bits are set,
# so rpmbuild can do whatever modifications it does post-%%install
INSTALL="%{__install} -p"
INSTALL_PROGRAM="\${INSTALL} -m 0755"
INSTALL_LIB="\${INSTALL} -m 0755"
INSTALL_MAN="\${INSTALL} -m 0644"
INSTALL_DATA="\${INSTALL} -m 0644"

CFLAGS="%{build_cflags}"
LDFLAGS="%{build_ldflags}"
EOF

%build
./configure
%make_build

%install
export EXCLUDE_FROM_COMPRESS=mandoc.db
%make_install

# ghost
touch %{buildroot}%{_mandir}/mandoc.db

%post
%create_ghostfile %{_mandir}/mandoc.db root root 644

%transfiletriggerin -p <lua> -- %{_mandir}
if posix.access("%{_mandir}/mandoc.db") then
  rpm.execute("%{_sbindir}/mandoc.makewhatis", "-a", "-T", "utf8", "%{_mandir}")
end
io.flush()

%transfiletriggerpostun -p <lua> -- %{_mandir}
if posix.access("%{_mandir}/mandoc.db") then
  rpm.execute("%{_sbindir}/mandoc.makewhatis", "-a", "-T", "utf8", "%{_mandir}")
end
io.flush()

%files
%license LICENSE
%doc NEWS TODO
%{_bindir}/mandoc
%{_bindir}/mandoc.apropos
%{_bindir}/demandoc
%{_bindir}/mandoc.man
%{_bindir}/mandoc.soelim
%{_bindir}/mandoc.whatis
%{_sbindir}/mandoc.makewhatis
%{_mandir}/man1/*.1*
%{_mandir}/man5/*.5*
%{_mandir}/man7/*.7*
%{_mandir}/man8/*.8*
%ghost %{_mandir}/mandoc.db


%changelog
* Sat Jan 27 2024 wally <wally> 1.14.6-4.mga10
+ Revision: 2035499
- use 'less -FR' as pager
- create mandoc.db in %%post
- replace filetrigger lua scriptlets with simpler transfiletriggers

* Sat Jan 27 2024 wally <wally> 1.14.6-3.mga10
+ Revision: 2035382
- install files with mandoc prefix
- drop separate mandoc-bin pkg
- fix file permissions
- don't compress mandoc.db

* Fri Jan 26 2024 philippedidier <philippedidier> 1.14.6-2.mga10
+ Revision: 2035035
- adapted spec file and patch from OpenSuse
- the previous spec file from Fedora could not build
+ neoclust <neoclust>
- imported package mandoc


* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.14.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Mon Dec 20 2021 David Cantrell <dcantrell@redhat.com> - 1.14.6-1
- Upgrade to mandoc-1.14.6 (#2005601)

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.14.5-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.14.5-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.14.5-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed May 20 2020 David Cantrell <dcantrell@redhat.com> - 1.14.5-12
- Drop explicit Requires for libmandoc package (#1837690)

* Tue May 19 2020 David Cantrell <dcantrell@redhat.com> - 1.14.5-11
- Per discussion with upstream, drop the shared library patch

* Tue Apr 14 2020 Björn Esser <besser82@fedoraproject.org> - 1.14.5-10
- libmandoc.so must be linked with COMPAT_OBJS
- Add patch to fix configure script
- Replace plain make with %%make_build

* Mon Mar 09 2020 David Cantrell <dcantrell@redhat.com> - 1.14.5-9
- BR perl-interpreter

* Mon Mar 09 2020 Nikola Forró <nforro@redhat.com> - 1.14.5-8
- Do not use alternatives for mdoc.7

* Thu Mar 05 2020 David Cantrell <dcantrell@redhat.com> - 1.14.5-7
- Build everything using -fPIC

* Thu Mar 05 2020 David Cantrell <dcantrell@redhat.com> - 1.14.5-6
- Include libmandoc.a in libmandoc-devel

* Tue Feb 25 2020 David Cantrell <dcantrell@redhat.com> - 1.14.5-5
- Split alternatives in to 4 sets (nforro)
- Use default names for binaries and man pages (nforro)
- Do not compress man pages (nforro)
- Add missing %%preun requirement (nforro)

* Mon Feb 24 2020 David Cantrell <dcantrell@redhat.com> - 1.14.5-4
- Install the user tools using alternatives (#1785308)

* Thu Feb 06 2020 David Cantrell <dcantrell@redhat.com> - 1.14.5-3
- Simplify the compat preprocessor tests (#1799629)

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.14.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Wed Oct 16 2019 David Cantrell <dcantrell@redhat.com> - 1.14.5-1
- Update to mandoc-1.14.5

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.14.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon Mar 25 2019 David Shea <dshea@redhat.com> - 1.14.4-2
- Move mdoc.7 to mandoc_mdoc.7 (#1691793)

* Thu Feb  7 2019 David Shea <dshea@redhat.com> - 1.14.4-1
- Initial package
